==> python-sfml_1.4.orig.tar.gz: SFML-1.4/python/src/Drawable.hpp <==
////////////////////////////////////////////////////////////
//
// PySFML - Python binding for SFML (Simple and Fast Multimedia Library)
// Copyright (C) 2007, 2008 Rémi Koenig (remi.k2620@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef __PYDRAWABLE_H
#define __PYDRAWABLE_H

#include <SFML/Graphics/Drawable.hpp>
#include <SFML/Graphics/RenderWindow.hpp>

#include <Python.h>
#include <structmember.h>

#include "Color.hpp"
#include "RenderWindow.hpp"


class CustomDrawable : public sf::Drawable
{
protected :
	virtual void Render(sf::RenderTarget& Target) const;
public :
	PySfRenderWindow *RenderWindow;
	PyObject *RenderFunction;
};


typedef struct {
	PyObject_HEAD
	CustomDrawable *obj;
} PySfDrawable;

#endif

==> python-sfml_1.5.orig.tar.gz: SFML-1.5/python/src/Drawable.hpp <==
////////////////////////////////////////////////////////////
//
// PySFML - Python binding for SFML (Simple and Fast Multimedia Library)
// Copyright (C) 2007, 2008 Rémi Koenig (remi.k2620@gmail.com)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

#ifndef __PYDRAWABLE_H
#define __PYDRAWABLE_H

#include <Python.h>

#include <SFML/Graphics/Drawable.hpp>

#include "RenderWindow.hpp"


class CustomDrawable : public sf::Drawable
{
protected :
	virtual void Render(sf::RenderTarget& Target) const;
public :
	PySfRenderWindow *RenderWindow;
	PyObject *RenderFunction;
};


typedef struct {
	PyObject_HEAD
	bool IsCustom;
	CustomDrawable *obj;
} PySfDrawable;

#endif
